@@ -9,7 +9,7 @@
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
- by the membership of KDE e.V.), which shall act as a proxy 
+ by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.
 
  This program is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 #include <kacceleratormanager.h>
 #include <kactioncollection.h>
 #include <KNewStuff3/KNS3/DownloadDialog>
+#include <KNewStuff3/KNSCore/Engine>
 #include <KConfigGroup>
 
 #include "WorkSheet.h"
@@ -142,7 +143,7 @@ void Workspace::newWorkSheet()
     mSheetList.append( sheet );
     setCurrentIndex(indexOf( sheet ));
     connect( sheet, &WorkSheet::titleChanged,
-	     this, &Workspace::updateSheetTitle);
+         this, &Workspace::updateSheetTitle);
   }
 }
 void Workspace::contextMenu (int index, const QPoint &point) {
@@ -290,8 +291,19 @@ void Workspace::uploadHotNewWorksheet()
     WorkSheet *currentWorksheet = currentWorkSheet();
     if(!currentWorksheet)
         return;
-
-    KMessageBox::information(this, i18n("<qt>To propose the current custom tab as a new System Monitor tab, email <br><a href=\"file:%1\">%2</a><br> to <a href=\"mailto:john.tapsell@kde.org?subject='System Monitor Tab'&attach='file://%2'\">john.tapsell@kde.org</a></qt>", currentWorksheet->fullFileName().section('/',0,-2), currentWorksheet->fullFileName()), i18n("Upload custom System Monitor tab"), QString(), KMessageBox::AllowLink);
+    KNSCore::Engine engine;
+    engine.init(QStringLiteral("ksysguard.knsrc"));
+    Q_ASSERT(engine.categories().size() == 1);
+    KMessageBox::information(this,
+                             xi18nc("@info",
+                                 "<para>You can publish your custom tab on the <link url='%1'>KDE Store</link> in the <icode>%2</icode> category.</para>"
+                                 "<para><filename>%3</filename></para>",
+                                    QStringLiteral("https://store.kde.org"),
+                                    engine.categories().at(0),
+                                    currentWorksheet->fullFileName()),
+                             i18n("Upload custom System Monitor tab"),
+                             QString(),
+                             KMessageBox::AllowLink);
 }
 void Workspace::getHotNewWorksheet()
 {
@@ -314,8 +326,8 @@ bool Workspace::restoreWorkSheet( const QString &fileName, bool switchToTab)
   QString baseName = fileName.right( fileName.length() - fileName.lastIndexOf( '/' ) - 1 );
 
   foreach( WorkSheet *sheet, mSheetList ) {
-	  if(sheet->fileName() == baseName)
-		  return false; //Don't add the same sheet twice
+      if(sheet->fileName() == baseName)
+          return false; //Don't add the same sheet twice
   }
 
   WorkSheet *sheet = new WorkSheet( 0 );
